use std::collections::HashMap;

pub struct SourceList {
    pub blocks: Vec<String>,
    pub confidence: u8,
}

impl SourceList {
    pub fn new() -> Self {
        SourceList {
            blocks: Vec::new(),
            confidence: 100,
        }
    }
}

impl From<Vec<String>> for SourceList {
    fn from(blocked: Vec<String>) -> Self {
        SourceList {
            blocks: blocked,
            confidence: 100,
        }
    }
}

pub struct TrustMaps {
    pub blocks: HashMap<String, usize>,
}

impl TrustMaps {
    pub fn new() -> TrustMaps {
        TrustMaps {
            blocks: HashMap::new(),
        }
    }

    pub fn add_source(&mut self, src: &SourceList) -> &mut TrustMaps {
        for host in src.blocks.iter() {
            let entry = self.blocks.entry(host.to_string()).or_insert(0);
            *entry += src.confidence as usize;
        }
        self
    }

    pub fn remove_source(&mut self, src: &SourceList) -> &mut TrustMaps {
        // If blocks already empty, nothing to remove so just return
        if self.blocks.is_empty() {
            return self;
        }

        // Iterate over host strings in source list
        for host in src.blocks.iter() {
            // If the host isn't in the output list, then skip
            if !self.blocks.contains_key(host) {
                continue;
            }

            // Host is valid entry, subtract confidence value and saturate at 0
            self.blocks.entry(host.to_string()).and_modify(|v| {
                *v = v.saturating_sub(src.confidence as usize);
            });
        }

        // Finally, if any value became zero, remove the pair from the map
        self.blocks.retain(|_, v| *v != 0);

        self
    }
}