#![cfg(test)]

use super::*;
use list::*;
use std::collections::HashMap;

#[test]
fn add_lists() {
    let hosts1 = vec![
        String::from("example.com"),
        String::from("example.org"),
        String::from("example.net"),
    ];
    let hosts2 = vec![String::from("example.com"), String::from("example.org")];
    let hosts3 = vec![String::from("example.com")];

    let src1 = SourceList::from(hosts1);
    let src2 = SourceList::from(hosts2);
    let src3 = SourceList::from(hosts3);

    let mut output = TrustMaps::new();
    output.add_source(&src1).add_source(&src2).add_source(&src3);

    let test_map = HashMap::from([
        (String::from("example.com"), 300),
        (String::from("example.org"), 200),
        (String::from("example.net"), 100),
    ]);
    assert_eq!(test_map, output.blocks);
}

#[test]
fn remove_lists() {
    let hosts1 = vec![
        String::from("example.com"),
        String::from("example.org"),
        String::from("example.net"),
    ];
    let hosts2 = vec![String::from("example.com"), String::from("example.org")];
    let hosts3 = vec![String::from("example.com")];

    let src1 = SourceList::from(hosts1);
    let src2 = SourceList::from(hosts2);
    let src3 = SourceList::from(hosts3);

    let mut output = TrustMaps::new();
    output
        .add_source(&src1)
        .add_source(&src2)
        .add_source(&src3)
        .remove_source(&src3)
        .remove_source(&src3)
        .remove_source(&src3)
        .remove_source(&src3);

    let test_map = HashMap::from([
        (String::from("example.org"), 200),
        (String::from("example.net"), 100),
    ]);

    assert_eq!(test_map, output.blocks);
}
